@@ -3,7 +3,7 @@ use quote::quote;
 pub fn generate_stable_read() -> proc_macro2::TokenStream {
     quote! {
         #[pymethod]
-        fn stable_read(&self, offset_py_object_ref: PyObjectRef, length_py_object_ref: PyObjectRef, vm: &VirtualMachine) -> PyObjectRef {
+        fn _kybra_stable_read(&self, offset_py_object_ref: PyObjectRef, length_py_object_ref: PyObjectRef, vm: &VirtualMachine) -> PyObjectRef {
             let offset: u32 = offset_py_object_ref.try_from_vm_value(vm).unwrap();
             let length: u32 = length_py_object_ref.try_from_vm_value(vm).unwrap();
 
