@@ -1,4 +1,6 @@
 pub mod async_result_handler;
 pub mod ic_object;
 pub mod kybra_serde;
+pub mod stable_b_tree_map;
+pub mod tuple;
 pub mod vm_value_conversion;
